@@ -1,6 +1,6 @@
 import numpy as np
 from .functions import *
-from .evaluation import *
+from .metrics import *
 
 class LiveStats():
     def __init__(self, type=-1, f1=0, f2=1, row_select="limited"):
