@@ -1,6 +1,6 @@
 import numpy as np
 
-def accuracy(self, targets, outputs):
+def accuracy(targets, outputs):
     accuracy = 1e-10
     outputs = np.array(outputs)
     if outputs.shape[1] > 1:
